@@ -134,7 +134,7 @@ fn derive_check_bytes(mut input: DeriveInput) -> Result<TokenStream, Error> {
     }
     impl_input_generics
         .params
-        .push(parse_quote! { __C: ?Sized });
+        .insert(0, parse_quote! { __C: ?Sized });
 
     let name = &input.ident;
 
@@ -178,7 +178,7 @@ fn derive_check_bytes(mut input: DeriveInput) -> Result<TokenStream, Error> {
                     impl #impl_generics CheckBytes<__C> for #name #ty_generics #check_where {
                         type Error = StructCheckError;
 
-                        unsafe fn check_bytes<'a>(value: *const Self, context: &mut __C) -> Result<&'a Self, Self::Error> {
+                        unsafe fn check_bytes<'__bytecheck>(value: *const Self, context: &mut __C) -> Result<&'__bytecheck Self, Self::Error> {
                             let bytes = value.cast::<u8>();
                             #(#field_checks)*
                             Ok(&*value)
@@ -217,7 +217,7 @@ fn derive_check_bytes(mut input: DeriveInput) -> Result<TokenStream, Error> {
                     impl #impl_generics CheckBytes<__C> for #name #ty_generics #check_where {
                         type Error = TupleStructCheckError;
 
-                        unsafe fn check_bytes<'a>(value: *const Self, context: &mut __C) -> Result<&'a Self, Self::Error> {
+                        unsafe fn check_bytes<'__bytecheck>(value: *const Self, context: &mut __C) -> Result<&'__bytecheck Self, Self::Error> {
                             let bytes = value.cast::<u8>();
                             #(#field_checks)*
                             Ok(&*value)
@@ -230,7 +230,7 @@ fn derive_check_bytes(mut input: DeriveInput) -> Result<TokenStream, Error> {
                     impl #impl_generics CheckBytes<__C> for #name #ty_generics #impl_where_clause {
                         type Error = Infallible;
 
-                        unsafe fn check_bytes<'a>(value: *const Self, context: &mut __C) -> Result<&'a Self, Self::Error> {
+                        unsafe fn check_bytes<'__bytecheck>(value: *const Self, context: &mut __C) -> Result<&'__bytecheck Self, Self::Error> {
                             Ok(&*value)
                         }
                     }
@@ -420,7 +420,7 @@ fn derive_check_bytes(mut input: DeriveInput) -> Result<TokenStream, Error> {
                 impl #impl_generics CheckBytes<__C> for #name #ty_generics #check_where {
                     type Error = EnumCheckError<#repr>;
 
-                    unsafe fn check_bytes<'a>(value: *const Self, context: &mut __C) -> Result<&'a Self, Self::Error> {
+                    unsafe fn check_bytes<'__bytecheck>(value: *const Self, context: &mut __C) -> Result<&'__bytecheck Self, Self::Error> {
                         let tag = *value.cast::<#repr>();
                         match tag {
                             #(#tag_variant_values => #check_arms)*
